<p align="center">
  <img width="128" align="center" src="https://cdn.jsdelivr.net/gh/retrofor/iamai@master/docs/_static/retro.png" />
  <img width="60" align="right" src="https://cdn.jsdelivr.net/gh/retrofor/iamai@master/docs/_static/icons/retro_plus.png" />
  <img width="60" align="left" src="https://images.repography.com/40962158/retrofor/iamai/structure/afEhYzXo83AMGRNy9EzPPQcX9ECBKj2gOPhvmpzMFSg/DQMxDEhfNZdq6zFhjPa1G61Bg9g-DRhQiwNY-W2ZHVE_table.svg" />
</p>
<br />
<h1 align="center">
  iamai
</h1>
<p align="center">
  <a href="https://discord.gg/9vG9352RXS"><img alt="Discord" src="https://img.shields.io/discord/1063871387527303188"></a>
  <a href="https://jq.qq.com/?_wv=1027&k=OOUmgrqx"><img alt="QQ群" src="https://img.shields.io/badge/-QQ群%20761859776-002FA7?style=flat-square&logo=Tencent QQ&logoColor=white"></a>
</p>
<p align="center">
  Comprehensive AI Toolkit for Multimodal Learning and Cross-Platform Robotics.
</p>
<p align="center">
  <a href="https://pypi.python.org/pypi/iamai">
    <img src="https://img.shields.io/pypi/v/iamai?style=flat-square" alt="pypi">
  </a>
  <img src="https://img.shields.io/badge/python-3.8+-blue?style=flat-square" alt="python">
  <br>
  <img src="https://results.pre-commit.ci/badge/github/retrofor/iamai/main.svg">
  <a href='https://iamai.is-a.dev/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/iamai/badge/?version=latest' alt='Documentation Status' />
</a>
  <br>
    <a style="text-decoration:none" href="https://www.codacy.com/gh/retrofor/iamai/dashboard?utm_source=github.com&utm_medium=referral&utm_content=retrofor/iamai&utm_campaign=Badge_Gradee" target="_blank">
    <img src="https://app.codacy.com/project/badge/Grade/f3611d85db764236b65fac956bdb53df" alt="Codacy Badge" />
  </a>
    <img src="https://img.shields.io/badge/code_style-black-000000.svg?style=flat-square" alt="Codacy Badge" />
</p>
<p align="center">
</p>
<p align="center">
<!-- onebot -->
  <a style="text-decoration:none" href="https://onebot.dev" target="_blank">
    <img src="https://img.shields.io/badge/-Onebot%2011-000020?style=flat-square&logo=data:image/png;base64, &logoColor=white" alt="onebotv11" />
    </a>
    <a href="https://www.kookapp.cn/">
      <img src="https://img.shields.io/badge/-%E5%BC%80%E9%BB%91%E5%95%A6Kook-83700?style=flat-square&logo=Discord&logoColor=white">
    </a>
    <!-- github -->
    <!-- <img src="https://img.shields.io/badge/-github-181717?style=flat-square&logo=github&logoColor=white"> -->
    <!-- discord -->
    <!-- <img src="https://img.shields.io/badge/-Discord-5865F2?style=flat-square&logo=Discord&logoColor=white"> -->
    <!-- bilibili live -->
    <img src="https://img.shields.io/badge/-BiliBili Live-00A1D6?style=flat-square&logo=Bilibili&logoColor=white">
    <br />
    <!-- dingtalk -->
    <img src="https://img.shields.io/badge/http/stream-DingTalk-blue?style=flat-square">
    <!-- <br> -->
    <!-- minecraft -->
    <!-- <img src="https://img.shields.io/badge/-Minecraft Server-62B47A?style=flat-square&logo=Minecraft&logoColor=white"> -->
    <!-- twitter -->
    <!-- <img src="https://img.shields.io/badge/-Twitter-1DA1F2?style=flat-square&logo=twitter&logoColor=white"> -->
    <!-- console -->
    <img src="https://img.shields.io/badge/-Console-4EAA25?style=flat-square&logo=GNU bash&logoColor=white">
    <!-- tg -->
    <!-- <img src="https://img.shields.io/badge/-Telegram-26A5E4?style=flat-square&logo=telegram&logoColor=white"> -->
    <!-- red -->
    <img src="https://img.shields.io/badge/Chronocat-Red-red?style=flat-square&logo=&logoColor=white">
    <!-- gensokyo -->
    <img src="https://img.shields.io/badge/Onebot11-Gensokyo-blue?style=flat-square&logo=[red](https://mirror.ghproxy.com/github.com/Hoshinonyaruko/Gensokyo/blob/main/frontend/public/icons/favicon-128x128.png)&logoColor=white">
  </a>
</p>
<p align="center">
</p>
<p align="center">
  <img src="https://img.shields.io/github/forks/retrofor/iamai?style=social" >
  <img src="https://img.shields.io/github/stars/retrofor/iamai?style=social" >
  <br>
  <img src="https://img.shields.io/github/watchers/retrofor/iamai?style=social" >
  <img src="https://img.shields.io/github/search/retrofor/iamai/goto?style=social" >
  <br>
  <img src="https://img.shields.io/github/repo-size/retrofor/iamai?style=social" >
  <img src="https://img.shields.io/github/languages/top/retrofor/iamai?style=social" >
</p>

<!-- start intro -->

Welcome to iamai, a powerful and comprehensive AI toolkit that seamlessly integrates multimodal machine learning capabilities with advanced tools for cross-platform robot development!

> 🌍 This library is designed to provide developers with a unified solution for creating intelligent systems that span multiple modalities and operate across diverse platforms. 

<!-- end intro -->

<!-- start index -->

- 🎪 **Interactive [docs](https://iamai.is-a.dev) &amp; [demos](https://iamai.is-a.dev/)**
- 🕶 **Seamless migration**: Works for **both** [Rasa]() and [GPT]() and more...
- ⚡ **Fully tree shakeable**: Only take what you want, [bundle size](https://iamai.retrofor.space/export-size)
- 🔩 **Flexible**: Configurable event filters and targets
- 🔌 **Optional [Add-ons](https://iamai.retrofor.space/add-ons)**: [Apscheduler](https://iamai.retrofor.space/add-ons/apscheduler), etc.
- 👍 **Cross-platform**: [dingtalk](https://iamai.retrofor.space/guide/dingtalk-adapter.html) etc.

<!-- end index -->

First of all, in the field of machine learning, we drew inspiration from the excellent design of [Hugging Face](https://huggingface.co)'s [transformers](https://github.com/huggingface/transformers) 🤗 for the use of pre-trained models. We would like to express our gratitude to the authors of Hugging Face and their open-source community.

Secondly, regarding the cross-platform robot framework, it is primarily based on [st](https://github.com/st1020)'s [alicebot](https://github.com/AliceBotProject/alicebot). We have made numerous adaptations to make it compatible with machine learning. We would like to thank the st and alicebot open-source communities for their contributions.

To avoid any potential disputes or misunderstandings, we have listed the licenses of the projects we have used and express our gratitude towards them. please see [credits.md](./credits.md).

<!-- ## 特别的鸣谢

我们很乐意在下面列出对IamAI的发展方向和动机有着[重大贡献](https://academic.jyunko.cn/2023/04/04/April-Fours-Day.html)的组织和个人。如果你认为你应该在这里，请至少要像Bryan不可思议那样在文章底栏留言或者发送邮件联系我们 :D

个人: [A60](https://github.com/djkcyl)、[Bryan不可思议](https://github.com/ProgramRipper)
组织: [GariaProject](https://github.com/GraiaProject)

如果没有以上个人和组织的帮助，IamAI将不会有现在的样子。我们真的很感谢他们。 -->

## License

[MIT](https://github.com/retrofor/iamai/blob/main/LICENSE) © 2023-PRESENT [Retro for Wut?](https://github.com/retrofor).

[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fretrofor%2Fiamai.svg?type=shield)](https://app.fossa.com/projects/git%2Bgithub.com%2Fretrofor%2Fiamai?ref=badge_shield)

<a href="https://app.fossa.com/projects/git%2Bgithub.com%2Fretrofor%2Fiamai?ref=badge_large" alt="FOSSA Status"><img src="https://app.fossa.com/api/projects/git%2Bgithub.com%2Fretrofor%2Fiamai.svg?type=large"/></a>
